def configureSimulation(sim):
   import CompuCell
   import CompuCellSetup

   ppd=CompuCell.PottsParseData()
   ppd.DebugOutputFrequency(40)
   ppd.Steps(30000)
   ppd.Anneal(10)
   ppd.Temperature(5)
   ppd.Flip2DimRatio(1.0)
   ppd.NeighborOrder(2)
   ppd.Dimensions(CompuCell.Dim3D(100,100,1))
   ppd.LatticeType("Hexagonal")



   ctpd=CompuCell.CellTypeParseData()

   ctpd.CellType("Medium",0)
   ctpd.CellType("Condensing",1)
   ctpd.CellType("NonCondensing",2)

   cpd=CompuCell.ContactParseData()
   cpd.Energy("Medium","Medium",0)
   cpd.Energy("NonCondensing","NonCondensing",16)
   cpd.Energy("Condensing","Condensing",2)
   cpd.Energy("NonCondensing","Condensing",11)
   cpd.Energy("NonCondensing","Medium",16)
   cpd.Energy("Condensing","Medium",16)

   vpd=CompuCell.VolumeParseData()
   vpd.LambdaVolume(1.0)
   vpd.TargetVolume(25.0)


   bipd=CompuCell.BlobInitializerParseData()
   region=bipd.Region()
   region.Center(CompuCell.Point3D(50,50,0))
   region.Radius(40)
   region.Types("Condensing")
   region.Types("NonCondensing")
   region.Width(5)


   CompuCellSetup.registerPotts(sim,ppd)

   CompuCellSetup.registerPlugin(sim,ctpd)
   CompuCellSetup.registerPlugin(sim,cpd)
   CompuCellSetup.registerPlugin(sim,vpd)

   CompuCellSetup.registerSteppable(sim,bipd)

import sys
from os import environ
from os import getcwd
import string
sys.path.append(environ["PYTHON_MODULE_PATH"])
sys.path.append(getcwd()+"/examples_PythonTutorial")

import CompuCellSetup

sim,simthread = CompuCellSetup.getCoreSimulationObjects()

configureSimulation(sim)

CompuCellSetup.initializeSimulationObjects(sim,simthread)


from PySteppables import SteppableRegistry
steppableRegistry=SteppableRegistry()


from cellsort_2D_steppables import ContactSteeringExercise8
contactSteeringExercise8=ContactSteeringExercise8(sim,100)
contactSteeringExercise8.setTSorted(8000)
contactSteeringExercise8.setTCheckerboard(1000)
steppableRegistry.registerSteppable(contactSteeringExercise8)


CompuCellSetup.mainLoop(sim,simthread,steppableRegistry)

